==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2107_155.zip: ronportal/ronportal/kapacity/planovanikapacit_planovanaabsence.php <==
<?php
/**
 * stanislav.elbl, 13.09.2019
 */

namespace RonPortal\Kapacity;

use Ron\DateUtils;
use Ron\StringUtils;
use Ron\DB\Database;
use Ron\DB\DBException;
use Ron\TextManager;
use RonPortal\RonPortalSettings;

/**
 * Class PlanovaniKapacit_PlanovanaAbsence
 * @package RonPortal\Kapacity
 */
class PlanovaniKapacit_PlanovanaAbsence
{
    const ABSENCE_SQL_DETAIL_INDEX = 17;

    public $idPP;
    /** @var int    primarni klic pro odkaz na editaci */
    public $poradi;
    /** @var int */
    public $datumOd;
    /** @var int */
    public $datumDo;

    /** @var string */
    public $kod;
    /** @var string */
    public $popis;

    //public $f_puvodni_kod;
    public $kod2; // pokud je povolen rezim uprav, obsahuje druhy kod

    public $podrobnostiAbsence;

    public $delka; // 0 = cela smena, 1 = 1.pulka, ...
    public $casOd;
    public $casDo;

    public $schvaleni;
    public $zkratka;
    public $barva;
    public $autoSchvalovat;

    public $zkratka2;
    public $barva2;

    public $poznamka;

    public $kodTypuRozdeleni;
    public $rozdeleni;
    public $popisRozdeleni;

    public $update_UserName;
    public $update_Timestamp;
    public $insert_UserName;
    public $insert_Timestamp;

    public $schvalil;
    public $datumSchvaleni;

    public $lzeEditovat; // pro detail
    public $lzeSmazat;


    public function __construct()
    {
    }


    /**
     * @param Database $database
     * @param array    $row
     */
    public function nactiData($database, $row)
    {
        // nacita zakladni data pro hromadne zobrazeni
        $this ->idPP = (int)$row[16];
        $this ->poradi = (int)$row[6];

        $this ->datumOd = $database ->stringToTimestamp($row[0]);
        $this ->datumDo = $database ->stringToTimestamp($row[1]);
        $this ->kod = $row[2];
        $this ->popis = $row[10];

        $this ->schvaleni = $row[3]; // 0, 1, 2
        $this ->zkratka = $row[4];
        $this ->barva = $row[5];

        if (RonPortalSettings::getIntValue(KapacitySettings::POVOLIT_REZIM_UPRAV)) {
            $this ->zkratka2 = $row[13];
            $this ->barva2 = $row[14];
        }

        $this ->delka = (int)$row[7];
        $this ->casOd = $database ->stringToTimeOfDay($row[8]);
        $this ->casDo = $database ->stringToTimeOfDay($row[9]);

        //$this ->f_puvodni_kod = $row[11];
        $this ->kod2 = $row[11];
        $this ->autoSchvalovat = (int)$row[12];

        $this ->podrobnostiAbsence = $this ->popis . ' ';

        $datumabsencestr = date('j.n.Y', $this ->datumOd);
        if ($this ->datumDo > $this ->datumOd) {
            $datumabsencestr .= ' - ' . date('j.n.Y', $this ->datumDo);
        }

        switch ($this ->delka) {
            case 0 :
                $this ->podrobnostiAbsence .= $datumabsencestr;
                break; // cela smena

            case 1 :
                $this ->podrobnostiAbsence .= $datumabsencestr . ' (' . TextManager::_('Absence_pulka_smeny1') . ')';
                break;

            case 2 :
                $this ->podrobnostiAbsence .= $datumabsencestr . ' (' . TextManager::_('Absence_pulka_smeny2') . ')';
                break;

            case 3 :
                $this ->podrobnostiAbsence .=
                    $datumabsencestr . ' (' . DateUtils::minutesToString($this ->casOd * 60) .
                    ' - ' .
                    DateUtils::minutesToString($this ->casDo * 60) . ')';
                break;

            case 4 :
                $this ->podrobnostiAbsence .=
                    date('j.n.Y ', $this ->datumOd) . DateUtils::minutesToString($this ->casOd * 60) .
                    ' - ' .
                    date('j.n.Y ', $this ->datumDo) . DateUtils::minutesToString($this ->casDo * 60);
                break;
        }

        if (count($row) > self::ABSENCE_SQL_DETAIL_INDEX) {
            $this->update_UserName = $row[self::ABSENCE_SQL_DETAIL_INDEX + 0];
            $this->update_Timestamp = $row[self::ABSENCE_SQL_DETAIL_INDEX + 1] ? $database->stringToTimestamp($row[self::ABSENCE_SQL_DETAIL_INDEX + 1]) : '';
            $this->poznamka = $row[self::ABSENCE_SQL_DETAIL_INDEX + 2];

            $this->schvalil = $row[self::ABSENCE_SQL_DETAIL_INDEX + 6];
            $this->datumSchvaleni = $database->stringToTimestamp($row[self::ABSENCE_SQL_DETAIL_INDEX + 7]);

            $this->kodTypuRozdeleni = $row[self::ABSENCE_SQL_DETAIL_INDEX + 3];
            $this->rozdeleni = $row[self::ABSENCE_SQL_DETAIL_INDEX + 4];
            $this->popisRozdeleni = $row[self::ABSENCE_SQL_DETAIL_INDEX + 5];

            $this->insert_UserName = $row[self::ABSENCE_SQL_DETAIL_INDEX + 8];
            $this->insert_Timestamp = $row[self::ABSENCE_SQL_DETAIL_INDEX + 9] ? $database->stringToTimestamp($row[self::ABSENCE_SQL_DETAIL_INDEX + 9]) : '';
        }
    }


    /**
     * @param Database $database
     * @param int|int[] $idPP
     * @param int $datumOd
     * @param int $datumDo
     * @param bool $detail
     * @param bool $rezimUprav
     * @return PlanovaniKapacit_PlanovanaAbsence[] vraci seznam absenci pro zadanou osobu a rozsah dnu
     * @throws DBException
     */
    public static function nactiAbsence($database, $idPP, $datumOd, $datumDo, $detail = false, $rezimUprav = false)
    {
        $result = [];

        $params = $database ->createParameters();

        $sqlDetail = '';
        if ($detail) {
            $sqlDetail .=
                ', Absence.Update_UserName, Absence.Update_Timestamp, ' . // self::ABSENCE_SQL_DETAIL_INDEX + 0,+1
                $database ->castWideMemo('Absence.Poznamka') . // +2
                ', Absence.KodTypuRozdeleni, Absence.Rozdeleni, Rozdeleni.Popis' . // +3..+5
                ', Absence.Schvalil, Absence.DatumSchvaleni' . // +6,+7
                ', Absence.Insert_UserName, Absence.Insert_Timestamp'; // +8,+9
        }

        if (!$rezimUprav  &&  RonPortalSettings::getIntValue(KapacitySettings::POVOLIT_REZIM_UPRAV)) {
            // SQL dotaz pro puvodni plan
            $sql =
                'SELECT Absence.DatumOd, Absence.DatumDo, Absence.OperaceDochazkyPuvodni, Absence.Schvaleni, ' . // 0-3
                ' OperaceDochazky.ZkratkaProPlanovani, OperaceDochazky.BarvaProVykresleni, ' . // 4,5
                ' Absence.Poradi, Absence.Delka, Absence.CasOd, Absence.CasDo, ' . // 6-9
                ' OperaceDochazky.Popis, Absence.OperaceDochazky, ' . // 10,11
                ' OperaceDochazky.Absence_AutoSchvalovat, ' . // 12
                ' OperaceNova.ZkratkaProPlanovani, OperaceNova.BarvaProVykresleni, OperaceNova.Popis, ' . // 13..15
                ' PracovniPomer.Id ' .
                $sqlDetail .
                ' FROM Absence INNER JOIN PracovniPomer' .
                '   ON Absence.RC = PracovniPomer.RC ' .
                '  AND Absence.OsobniCislo = PracovniPomer.OsobniCislo ' .
                '  AND Absence.DatumNastupu = PracovniPomer.DatumNastupu ' .
                ' LEFT OUTER JOIN OperaceDochazky ON OperaceDochazky.Kod = Absence.OperaceDochazkyPuvodni ' .
                ' LEFT OUTER JOIN OperaceDochazky OperaceNova ON OperaceNova.Kod = Absence.OperaceDochazky ' .
                ' LEFT OUTER JOIN Rozdeleni ' .
                '   ON Rozdeleni.KodTypuRozdeleni = Absence.KodTypuRozdeleni ' .
                '  AND Rozdeleni.Kod = Absence.Rozdeleni ';
        } else if (RonPortalSettings::getIntValue(KapacitySettings::POVOLIT_REZIM_UPRAV)) {
            // SQL dotaz pro rezim uprav
            $sql =
                'SELECT Absence.DatumOd, Absence.DatumDo, Absence.OperaceDochazky, Absence.Schvaleni, ' . // 0-3
                ' OperaceDochazky.ZkratkaProPlanovani, OperaceDochazky.BarvaProVykresleni, ' . // 4,5
                ' Absence.Poradi, Absence.Delka, Absence.CasOd, Absence.CasDo, ' . // 6-9
                ' OperaceDochazky.Popis, Absence.OperaceDochazkyPuvodni, ' . // 10,11
                ' OperaceDochazky.Absence_AutoSchvalovat, ' . // 12
                ' OperacePuvodni.ZkratkaProPlanovani, OperacePuvodni.BarvaProVykresleni, OperacePuvodni.Popis, ' . // 13..15
                ' PracovniPomer.Id ' .
                $sqlDetail .
                ' FROM (Absence INNER JOIN PracovniPomer' .
                '   ON Absence.RC = PracovniPomer.RC' .
                '  AND Absence.OsobniCislo = PracovniPomer.OsobniCislo' .
                '  AND Absence.DatumNastupu = PracovniPomer.DatumNastupu)' .
                ' LEFT OUTER JOIN OperaceDochazky ON OperaceDochazky.Kod = Absence.OperaceDochazky ' .
                ' LEFT OUTER JOIN OperaceDochazky OperacePuvodni ON OperacePuvodni.Kod = Absence.OperaceDochazkyPuvodni ' .
                ' LEFT OUTER JOIN Rozdeleni ' .
                '   ON Rozdeleni.KodTypuRozdeleni = Absence.KodTypuRozdeleni ' .
                '  AND Rozdeleni.Kod = Absence.Rozdeleni ';
        } else {
            // rezim uprav se vubec nepouziva
            $sql =
                'SELECT Absence.DatumOd, Absence.DatumDo, Absence.OperaceDochazky, Absence.Schvaleni, ' . // 0-3
                ' OperaceDochazky.ZkratkaProPlanovani, OperaceDochazky.BarvaProVykresleni, ' . // 4,5
                ' Absence.Poradi, Absence.Delka, Absence.CasOd, Absence.CasDo, ' . // 6-9
                ' OperaceDochazky.Popis, Absence.OperaceDochazkyPuvodni, ' . // 10,11
                ' OperaceDochazky.Absence_AutoSchvalovat, ' . // 12
                ' NULL, NULL, NULL, ' . // 13..15
                ' PracovniPomer.Id ' .
                $sqlDetail .
                ' FROM Absence INNER JOIN PracovniPomer' .
                '   ON Absence.RC = PracovniPomer.RC ' .
                '  AND Absence.OsobniCislo = PracovniPomer.OsobniCislo ' .
                '  AND Absence.DatumNastupu = PracovniPomer.DatumNastupu ' .
                ' LEFT OUTER JOIN OperaceDochazky ON OperaceDochazky.Kod = Absence.OperaceDochazky ' .
                ' LEFT OUTER JOIN Rozdeleni ' .
                '   ON Rozdeleni.KodTypuRozdeleni = Absence.KodTypuRozdeleni ' .
                '  AND Rozdeleni.Kod = Absence.Rozdeleni ';
        }

        $sql .=
            ' WHERE Absence.Schvaleni <> 2  AND  Absence.Schvaleni <> 4 ' . // nenacita zamitnute a zrusene
            '   AND Absence.DatumDo >= ' . $params ->addParameter($database ->dateToParam($datumOd)) .
            '   AND Absence.DatumOd <= ' . $params ->addParameter($database ->dateToParam($datumDo));

        if (is_array($idPP)) {
            $sql .= ' AND (0 = 1';
            foreach ($idPP as $id) {
                $sql .= ' OR PracovniPomer.Id = ' . $params ->addParameter($id);
            }
            $sql .= ')';
        } else {
            $sql .= '   AND PracovniPomer.Id = ' . $params->addParameter($idPP);
        }

        $sql .=
            ' ORDER BY PracovniPomer.Id, Absence.DatumOd';

        $cursor = $database ->getSqlResult($sql, $params, 'Chyba v metode PlanovaniKapacit_PlanovanaAbsence::nactiAbsence!');

        while ($row = $cursor ->fetch()) {
            $absence = new PlanovaniKapacit_PlanovanaAbsence();
            $absence ->nactiData($database, $row);

            $result[] = $absence;
        }

        $cursor ->close();

        return $result;
    }


    /**
     * @param bool $detail
     * @return array
     */
    public function getJSON($detail = false)
    {
        $json = [];
        $json['datumOdStr'] = date('j.n.Y', $this ->datumOd);
        $json['datumDoStr'] = date('j.n.Y', $this ->datumDo);
        $json['delka'] = $this ->delka;
        $json['schvaleni'] = $this ->schvaleni;
        $json['autoSchvalovat'] = (int)$this ->autoSchvalovat;

        if ($detail && $this ->lzeEditovat) {
            $json['lzeEditovat'] = 1;
        }
        if ($detail && !$this ->lzeEditovat && $this ->lzeSmazat)  {
            $json['lzeSmazat'] = 1;
        }

        $json['kod'] = StringUtils::jsonText($this ->kod);
        if (RonPortalSettings::getIntValue(KapacitySettings::POVOLIT_REZIM_UPRAV)) {
            $json['kod2'] = StringUtils::jsonText($this ->kod2);
        }

        if ($detail  ||  $this ->delka === 3  ||  $this ->delka === 4) {
            $json['casOdStr'] = $this ->casOd ? DateUtils::minutesToString($this ->casOd * 60) : '';
            $json['casDoStr'] = $this ->casDo ? DateUtils::minutesToString($this ->casDo * 60) : '';
        }

        if ($detail) {
            $json['poradi'] = $this ->poradi;

            if ($this ->update_UserName) {
                $json['update_username'] = StringUtils::jsonText($this->update_UserName);
            }

            if ($this ->update_Timestamp) {
                $json['update_timestamp'] = date('j.n.Y G:i', $this->update_Timestamp);
            }

            if ($this ->insert_UserName) {
                $json['insert_username'] = StringUtils::jsonText($this->insert_UserName);
            }

            if ($this ->insert_Timestamp) {
                $json['insert_timestamp'] = date('j.n.Y G:i', $this->insert_Timestamp);
            }

            if ($this ->poznamka) {
                $json['poznamka'] = StringUtils::jsonText($this->poznamka);
            }

            if ($this ->kodTypuRozdeleni  &&  isset($this ->rozdeleni) ) {
                $json['kodTypuRozdeleni'] = $this ->kodTypuRozdeleni;
                $json['rozdeleni'] = StringUtils::jsonText($this ->rozdeleni);
                $json['popisRozdeleni'] = StringUtils::jsonText($this ->popisRozdeleni);
            }

            if ($this ->schvalil) {
                $json['schvalil'] = StringUtils::jsonText($this ->schvalil);
                $json['datumSchvaleni'] = date('j.n.Y G:i', $this ->datumSchvaleni);
            }
        } else {
            $json['podrobnosti'] = StringUtils::jsonText($this ->podrobnostiAbsence);
        }

        return $json;
    }

}

==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2302_169.zip: ronportal/ronportal/kapacity/planovanikapacit_planovanaabsence.php <==
<?php
/**
 * stanislav.elbl, 13.09.2019
 */

namespace RonPortal\Kapacity;

use Ron\DateUtils;
use Ron\GuiUtils;
use Ron\StringUtils;
use Ron\DB\Database;
use Ron\DB\DBException;
use Ron\TextManager;
use RonPortal\RonPortalSettings;

/**
 * Class PlanovaniKapacit_PlanovanaAbsence
 * @package RonPortal\Kapacity
 */
class PlanovaniKapacit_PlanovanaAbsence
{
    const ABSENCE_SQL_DETAIL_INDEX = 17;

    public $idPP;
    /** @var int    primarni klic pro odkaz na editaci */
    public $poradi;
    /** @var int */
    public $datumOd;
    /** @var int */
    public $datumDo;

    /** @var string */
    public $kod;
    /** @var string */
    public $popis;

    //public $f_puvodni_kod;
    public $kod2; // pokud je povolen rezim uprav, obsahuje druhy kod

    public $podrobnostiAbsence;

    public $delka; // 0 = cela smena, 1 = 1.pulka, ...
    /** @var float */
    public $casOd;
    /** @var float */
    public $casDo;

    public $schvaleni;
    public $zkratka;
    public $barva;
    public $autoSchvalovat;

    public $zkratka2;
    public $barva2;

    public $poznamka;

    public $kodTypuRozdeleni;
    public $rozdeleni;
    public $popisRozdeleni;

    public $update_UserName;
    public $update_Timestamp;
    public $insert_UserName;
    public $insert_Timestamp;

    public $schvalil;
    public $datumSchvaleni;

    public $lzeEditovat; // pro detail
    public $lzeSmazat;


    public function __construct()
    {
    }


    /**
     * @param Database $database
     * @param array    $row
     */
    private function nactiData($database, $row)
    {
        // nacita zakladni data pro hromadne zobrazeni
        $this ->idPP = (int)$row[16];
        $this ->poradi = (int)$row[6];

        $this ->datumOd = $database ->stringToTimestamp($row[0]);
        $this ->datumDo = $database ->stringToTimestamp($row[1]);
        $this ->kod = $row[2];
        $this ->popis = TextManager::_('db_operacedochazky_popis_' . $row[2], $row[10]);

        $this ->schvaleni = $row[3]; // 0, 1, 2
        $this ->zkratka = $row[4];
        $this ->barva = $row[5];

        if (RonPortalSettings::getIntValue(KapacitySettings::POVOLIT_REZIM_UPRAV)) {
            $this ->zkratka2 = $row[13];
            $this ->barva2 = $row[14];
        }

        $this ->delka = (int)$row[7];
        $this ->casOd = $database ->stringToTimeOfDay($row[8]);
        $this ->casDo = $database ->stringToTimeOfDay($row[9]);

        //$this ->f_puvodni_kod = $row[11];
        $this ->kod2 = $row[11];
        $this ->autoSchvalovat = (int)$row[12];

        $this ->podrobnostiAbsence = $this ->popis . ' ';

        $datumabsencestr = date('j.n.Y', $this ->datumOd);
        if ($this ->datumDo > $this ->datumOd) {
            $datumabsencestr .= ' - ' . date('j.n.Y', $this ->datumDo);
        }

        switch ($this ->delka) {
            case 0 :
                $this ->podrobnostiAbsence .= $datumabsencestr;
                break; // cela smena

            case 1 :
                $this ->podrobnostiAbsence .= $datumabsencestr . ' (' . TextManager::_('Absence_pulka_smeny1') . ')';
                break;

            case 2 :
                $this ->podrobnostiAbsence .= $datumabsencestr . ' (' . TextManager::_('Absence_pulka_smeny2') . ')';
                break;

            case 3 :
                $this ->podrobnostiAbsence .=
                    $datumabsencestr . ' (' . DateUtils::minutesToString($this ->casOd * 60) .
                    ' - ' .
                    DateUtils::minutesToString($this ->casDo * 60) . ')';
                break;

            case 4 :
                $this ->podrobnostiAbsence .=
                    date('j.n.Y ', $this ->datumOd) . DateUtils::minutesToString($this ->casOd * 60) .
                    ' - ' .
                    date('j.n.Y ', $this ->datumDo) . DateUtils::minutesToString($this ->casDo * 60);
                break;
        }

        if (count($row) > self::ABSENCE_SQL_DETAIL_INDEX) {
            $this->update_UserName = $row[self::ABSENCE_SQL_DETAIL_INDEX + 0];
            $this->update_Timestamp = $row[self::ABSENCE_SQL_DETAIL_INDEX + 1] ? $database->stringToTimestamp($row[self::ABSENCE_SQL_DETAIL_INDEX + 1]) : '';
            $this->poznamka = $row[self::ABSENCE_SQL_DETAIL_INDEX + 2];

            $this->schvalil = $row[self::ABSENCE_SQL_DETAIL_INDEX + 6];
            $this->datumSchvaleni = $database->stringToTimestamp($row[self::ABSENCE_SQL_DETAIL_INDEX + 7]);

            $this->kodTypuRozdeleni = $row[self::ABSENCE_SQL_DETAIL_INDEX + 3];
            $this->rozdeleni = $row[self::ABSENCE_SQL_DETAIL_INDEX + 4];
            $this->popisRozdeleni = $row[self::ABSENCE_SQL_DETAIL_INDEX + 5];

            $this->insert_UserName = $row[self::ABSENCE_SQL_DETAIL_INDEX + 8];
            $this->insert_Timestamp = $row[self::ABSENCE_SQL_DETAIL_INDEX + 9] ? $database->stringToTimestamp($row[self::ABSENCE_SQL_DETAIL_INDEX + 9]) : '';
        }
    }


    /**
     * @param Database $database
     * @param int|int[] $idPP
     * @param int $datumOd
     * @param int $datumDo
     * @param bool $detail
     * @param bool $rezimUprav
     * @return PlanovaniKapacit_PlanovanaAbsence[] vraci seznam absenci pro zadanou osobu a rozsah dnu
     * @throws DBException
     */
    public static function nactiAbsence($database, $idPP, $datumOd, $datumDo, $detail = false, $rezimUprav = false)
    {
        $result = [];

        $params = $database ->createParameters();

        $sqlDetail = '';
        if ($detail) {
            $sqlDetail .=
                ', Absence.Update_UserName, Absence.Update_Timestamp, ' . // self::ABSENCE_SQL_DETAIL_INDEX + 0,+1
                $database ->castWideMemo('Absence.Poznamka') . // +2
                ', Absence.KodTypuRozdeleni, Absence.Rozdeleni, Rozdeleni.Popis' . // +3..+5
                ', Absence.Schvalil, Absence.DatumSchvaleni' . // +6,+7
                ', Absence.Insert_UserName, Absence.Insert_Timestamp'; // +8,+9
        }

        if (!$rezimUprav  &&  RonPortalSettings::getIntValue(KapacitySettings::POVOLIT_REZIM_UPRAV)) {
            // SQL dotaz pro puvodni plan
            $sql =
                'SELECT Absence.DatumOd, Absence.DatumDo, Absence.OperaceDochazkyPuvodni, Absence.Schvaleni, ' . // 0-3
                ' OperaceDochazky.ZkratkaProPlanovani, OperaceDochazky.BarvaProVykresleni, ' . // 4,5
                ' Absence.Poradi, Absence.Delka, Absence.CasOd, Absence.CasDo, ' . // 6-9
                ' OperaceDochazky.Popis, Absence.OperaceDochazky, ' . // 10,11
                ' OperaceDochazky.Absence_AutoSchvalovat, ' . // 12
                ' OperaceNova.ZkratkaProPlanovani, OperaceNova.BarvaProVykresleni, OperaceNova.Popis, ' . // 13..15
                ' PracovniPomer.Id ' .
                $sqlDetail .
                ' FROM Absence INNER JOIN PracovniPomer' .
                '   ON Absence.RC = PracovniPomer.RC ' .
                '  AND Absence.OsobniCislo = PracovniPomer.OsobniCislo ' .
                '  AND Absence.DatumNastupu = PracovniPomer.DatumNastupu ' .
                ' LEFT OUTER JOIN OperaceDochazky ON OperaceDochazky.Kod = Absence.OperaceDochazkyPuvodni ' .
                ' LEFT OUTER JOIN OperaceDochazky OperaceNova ON OperaceNova.Kod = Absence.OperaceDochazky ' .
                ' LEFT OUTER JOIN Rozdeleni ' .
                '   ON Rozdeleni.KodTypuRozdeleni = Absence.KodTypuRozdeleni ' .
                '  AND Rozdeleni.Kod = Absence.Rozdeleni ';
        } else if (RonPortalSettings::getIntValue(KapacitySettings::POVOLIT_REZIM_UPRAV)) {
            // SQL dotaz pro rezim uprav
            $sql =
                'SELECT Absence.DatumOd, Absence.DatumDo, Absence.OperaceDochazky, Absence.Schvaleni, ' . // 0-3
                ' OperaceDochazky.ZkratkaProPlanovani, OperaceDochazky.BarvaProVykresleni, ' . // 4,5
                ' Absence.Poradi, Absence.Delka, Absence.CasOd, Absence.CasDo, ' . // 6-9
                ' OperaceDochazky.Popis, Absence.OperaceDochazkyPuvodni, ' . // 10,11
                ' OperaceDochazky.Absence_AutoSchvalovat, ' . // 12
                ' OperacePuvodni.ZkratkaProPlanovani, OperacePuvodni.BarvaProVykresleni, OperacePuvodni.Popis, ' . // 13..15
                ' PracovniPomer.Id ' .
                $sqlDetail .
                ' FROM (Absence INNER JOIN PracovniPomer' .
                '   ON Absence.RC = PracovniPomer.RC' .
                '  AND Absence.OsobniCislo = PracovniPomer.OsobniCislo' .
                '  AND Absence.DatumNastupu = PracovniPomer.DatumNastupu)' .
                ' LEFT OUTER JOIN OperaceDochazky ON OperaceDochazky.Kod = Absence.OperaceDochazky ' .
                ' LEFT OUTER JOIN OperaceDochazky OperacePuvodni ON OperacePuvodni.Kod = Absence.OperaceDochazkyPuvodni ' .
                ' LEFT OUTER JOIN Rozdeleni ' .
                '   ON Rozdeleni.KodTypuRozdeleni = Absence.KodTypuRozdeleni ' .
                '  AND Rozdeleni.Kod = Absence.Rozdeleni ';
        } else {
            // rezim uprav se vubec nepouziva
            $sql =
                'SELECT Absence.DatumOd, Absence.DatumDo, Absence.OperaceDochazky, Absence.Schvaleni, ' . // 0-3
                ' OperaceDochazky.ZkratkaProPlanovani, OperaceDochazky.BarvaProVykresleni, ' . // 4,5
                ' Absence.Poradi, Absence.Delka, Absence.CasOd, Absence.CasDo, ' . // 6-9
                ' OperaceDochazky.Popis, Absence.OperaceDochazkyPuvodni, ' . // 10,11
                ' OperaceDochazky.Absence_AutoSchvalovat, ' . // 12
                ' NULL, NULL, NULL, ' . // 13..15
                ' PracovniPomer.Id ' .
                $sqlDetail .
                ' FROM Absence INNER JOIN PracovniPomer' .
                '   ON Absence.RC = PracovniPomer.RC ' .
                '  AND Absence.OsobniCislo = PracovniPomer.OsobniCislo ' .
                '  AND Absence.DatumNastupu = PracovniPomer.DatumNastupu ' .
                ' LEFT OUTER JOIN OperaceDochazky ON OperaceDochazky.Kod = Absence.OperaceDochazky ' .
                ' LEFT OUTER JOIN Rozdeleni ' .
                '   ON Rozdeleni.KodTypuRozdeleni = Absence.KodTypuRozdeleni ' .
                '  AND Rozdeleni.Kod = Absence.Rozdeleni ';
        }

        $sql .=
            ' WHERE Absence.Schvaleni <> 2  AND  Absence.Schvaleni <> 4 ' . // nenacita zamitnute a zrusene
            '   AND Absence.DatumDo >= ' . $params ->addParameter($database ->dateToParam($datumOd)) .
            '   AND Absence.DatumOd <= ' . $params ->addParameter($database ->dateToParam($datumDo));

        if (is_array($idPP)) {
            $sql .= ' AND (0 = 1';
            foreach ($idPP as $id) {
                $sql .= ' OR PracovniPomer.Id = ' . $params ->addParameter($id);
            }
            $sql .= ')';
        } else {
            $sql .= '   AND PracovniPomer.Id = ' . $params->addParameter($idPP);
        }

        $sql .=
            ' ORDER BY PracovniPomer.Id, Absence.DatumOd';

        $cursor = $database ->getSqlResult($sql, $params, 'Chyba v metode PlanovaniKapacit_PlanovanaAbsence::nactiAbsence!');

        while ($row = $cursor ->fetch()) {
            $absence = new static();
            $absence ->nactiData($database, $row);

            $result[] = $absence;
        }

        $cursor ->close();

        return $result;
    }


    /**
     * @param bool $detail
     * @return array
     */
    public function getJSON($detail = false)
    {
        $json = [];
        $json['datumOdStr'] = date('j.n.Y', $this ->datumOd);
        $json['datumDoStr'] = date('j.n.Y', $this ->datumDo);
        $json['delka'] = $this ->delka;
        $json['schvaleni'] = $this ->schvaleni;
        $json['autoSchvalovat'] = (int)$this ->autoSchvalovat;

        if ($detail && $this ->lzeEditovat) {
            $json['lzeEditovat'] = 1;
        }
        if ($detail && !$this ->lzeEditovat && $this ->lzeSmazat)  {
            $json['lzeSmazat'] = 1;
        }

        $json['kod'] = StringUtils::jsonText($this ->kod);
        if (RonPortalSettings::getIntValue(KapacitySettings::POVOLIT_REZIM_UPRAV)) {
            $json['kod2'] = StringUtils::jsonText($this ->kod2);
        }

        if ($this ->zkratka) {
            $json['zkratka'] = StringUtils::jsonText($this->zkratka);
        }

        if ($this ->barva) {
            $json['barva'] = GuiUtils::getHtmlColor($this ->barva);
        }

        if ($detail  ||  $this ->delka === 3  ||  $this ->delka === 4) {
            $json['casOdStr'] = $this ->casOd ? DateUtils::minutesToString($this ->casOd * 60) : '';
            $json['casDoStr'] = $this ->casDo ? DateUtils::minutesToString($this ->casDo * 60) : '';
        }

        if ($detail) {
            $json['poradi'] = $this ->poradi;

            if ($this ->update_UserName) {
                $json['update_username'] = StringUtils::jsonText($this->update_UserName);
            }

            if ($this ->update_Timestamp) {
                $json['update_timestamp'] = date('j.n.Y G:i', $this->update_Timestamp);
            }

            if ($this ->insert_UserName) {
                $json['insert_username'] = StringUtils::jsonText($this->insert_UserName);
            }

            if ($this ->insert_Timestamp) {
                $json['insert_timestamp'] = date('j.n.Y G:i', $this->insert_Timestamp);
            }

            if ($this ->poznamka) {
                $json['poznamka'] = StringUtils::jsonText($this->poznamka);
            }

            if ($this ->kodTypuRozdeleni  &&  isset($this ->rozdeleni) ) {
                $json['kodTypuRozdeleni'] = $this ->kodTypuRozdeleni;
                $json['rozdeleni'] = StringUtils::jsonText($this ->rozdeleni);
                $json['popisRozdeleni'] = StringUtils::jsonText($this ->popisRozdeleni);
            }

            if ($this ->schvalil) {
                $json['schvalil'] = StringUtils::jsonText($this ->schvalil);
                $json['datumSchvaleni'] = date('j.n.Y G:i', $this ->datumSchvaleni);
            }
        } else {
            $json['podrobnosti'] = StringUtils::jsonText($this ->podrobnostiAbsence);
        }

        return $json;
    }

}
